@@ -67,7 +67,9 @@ type agentConfig struct {
 	DataDir                       string    `hcl:"data_dir"`
 	AdminSocketPath               string    `hcl:"admin_socket_path"`
 	InsecureBootstrap             bool      `hcl:"insecure_bootstrap"`
-	RetryBootstrap                bool      `hcl:"retry_bootstrap"`
+	RetryBootstrap                *bool     `hcl:"retry_bootstrap"`
+	RebootstrapMode               string    `hcl:"rebootstrap_mode"`
+	RebootstrapDelay              string    `hcl:"rebootstrap_delay"`
 	JoinToken                     string    `hcl:"join_token"`
 	LogFile                       string    `hcl:"log_file"`
 	LogFormat                     string    `hcl:"log_format"`
@@ -261,7 +263,7 @@ func (c *agentConfig) validate() error {
 	}
 
 	if c.TrustBundleUnixSocket != "" && c.TrustBundleURL == "" {
-		return fmt.Errorf("if trust_bundle_unix_socket is specified, so must be trust_bundle_url")
+		return errors.New("if trust_bundle_unix_socket is specified, so must be trust_bundle_url")
 	}
 	if c.TrustBundleURL != "" {
 		u, err := url.Parse(c.TrustBundleURL)
@@ -329,6 +331,7 @@ func parseFlags(name string, args []string, output io.Writer) (*agentConfig, err
 	flags := flag.NewFlagSet(name, flag.ContinueOnError)
 	flags.SetOutput(output)
 	c := &agentConfig{}
+	retryBootstrap := false
 
 	flags.StringVar(&c.ConfigPath, "config", defaultConfigPath, "Path to a SPIRE config file")
 	flags.StringVar(&c.DataDir, "dataDir", "", "A directory the agent can use for its runtime data")
@@ -345,7 +348,9 @@ func parseFlags(name string, args []string, output io.Writer) (*agentConfig, err
 	flags.StringVar(&c.TrustBundleFormat, "trustBundleFormat", "", fmt.Sprintf("Format of the bootstrap trust bundle, %q or %q", trustbundlesources.BundleFormatPEM, trustbundlesources.BundleFormatSPIFFE))
 	flags.BoolVar(&c.AllowUnauthenticatedVerifiers, "allowUnauthenticatedVerifiers", false, "If true, the agent permits the retrieval of X509 certificate bundles by unregistered clients")
 	flags.BoolVar(&c.InsecureBootstrap, "insecureBootstrap", false, "If true, the agent bootstraps without verifying the server's identity")
-	flags.BoolVar(&c.RetryBootstrap, "retryBootstrap", false, "If true, the agent retries bootstrap with backoff")
+	flags.BoolVar(&retryBootstrap, "retryBootstrap", true, "If true, the agent retries bootstrap with backoff")
+	flags.StringVar(&c.RebootstrapMode, "rebootstrapMode", "", "Can be one of 'never', 'auto', or 'always'")
+	flags.StringVar(&c.RebootstrapDelay, "rebootstrapDelay", "", "The time to delay after seeing a x509 cert mismatch from the server before rebootstrapping")
 	flags.BoolVar(&c.ExpandEnv, "expandEnv", false, "Expand environment variables in SPIRE config file")
 
 	c.addOSFlags(flags)
@@ -355,6 +360,12 @@ func parseFlags(name string, args []string, output io.Writer) (*agentConfig, err
 		return nil, err
 	}
 
+	flags.Visit(func(f *flag.Flag) {
+		if f.Name == "retryBootstrap" {
+			c.RetryBootstrap = &retryBootstrap
+		}
+	})
+
 	return c, nil
 }
 
@@ -387,7 +398,31 @@ func NewAgentConfig(c *Config, logOptions []log.Option, allowUnknownConfig bool)
 		return nil, err
 	}
 
-	ac.RetryBootstrap = c.Agent.RetryBootstrap
+	ac.RebootstrapMode = c.Agent.RebootstrapMode
+	switch ac.RebootstrapMode {
+	case agent.RebootstrapNever:
+	case agent.RebootstrapAuto:
+	case agent.RebootstrapAlways:
+	case "":
+		ac.RebootstrapMode = agent.RebootstrapNever
+	default:
+		return nil, fmt.Errorf("unknown rebootstrap mode specified: %s", ac.RebootstrapMode)
+	}
+	if ac.RebootstrapMode != agent.RebootstrapNever && c.Agent.InsecureBootstrap {
+		return nil, errors.New("insecure_bootstrap option can not be used with rebootstrapping")
+	}
+	if ac.RebootstrapMode != agent.RebootstrapNever && c.Agent.RetryBootstrap != nil {
+		return nil, errors.New("you can not set retry_bootstrap when using reboostrap_mode")
+	}
+
+	if c.Agent.RebootstrapDelay == "" {
+		c.Agent.RebootstrapDelay = "10m"
+	}
+	delay, err := time.ParseDuration(c.Agent.RebootstrapDelay)
+	if err != nil {
+		return nil, fmt.Errorf("error parsing rebootstrap delay duration: %w", err)
+	}
+	ac.RebootstrapDelay = delay
 
 	if c.Agent.Experimental.SyncInterval != "" {
 		var err error
@@ -426,6 +461,12 @@ func NewAgentConfig(c *Config, logOptions []log.Option, allowUnknownConfig bool)
 		ac.LogReopener = log.ReopenOnSignal(logger, reopenableFile)
 	}
 
+	ac.RetryBootstrap = true
+	if c.Agent.RetryBootstrap != nil {
+		ac.Log.Warn("The 'retry_bootstrap' configuration is deprecated. It will be removed in SPIRE 1.14. Please test without the flag before upgrading.")
+		ac.RetryBootstrap = *c.Agent.RetryBootstrap
+	}
+
 	ac.UseSyncAuthorizedEntries = true
 	if c.Agent.Experimental.UseSyncAuthorizedEntries != nil {
 		ac.Log.Warn("The 'use_sync_authorized_entries' configuration is deprecated. The option to disable it will be removed in SPIRE 1.13.")
@@ -477,6 +518,9 @@ func NewAgentConfig(c *Config, logOptions []log.Option, allowUnknownConfig bool)
 		TrustBundlePath:       c.Agent.TrustBundlePath,
 		TrustBundleURL:        c.Agent.TrustBundleURL,
 		TrustBundleUnixSocket: c.Agent.TrustBundleUnixSocket,
+		TrustDomain:           c.Agent.TrustDomain,
+		ServerAddress:         c.Agent.ServerAddress,
+		ServerPort:            c.Agent.ServerPort,
 	}
 
 	ac.TrustBundleSources = trustbundlesources.New(ts, ac.Log.WithField("Logger", "TrustBundleSources"))
