@@ -7,7 +7,6 @@ import (
 	"net/url"
 
 	"github.com/spiffe/go-spiffe/v2/spiffeid"
-	"github.com/zeebo/errs"
 )
 
 func MakeCSR(privateKey any, spiffeID spiffeid.ID) ([]byte, error) {
@@ -33,7 +32,7 @@ func MakeCSRWithoutURISAN(privateKey any) ([]byte, error) {
 func makeCSR(privateKey any, template *x509.CertificateRequest) ([]byte, error) {
 	csr, err := x509.CreateCertificateRequest(rand.Reader, template, privateKey)
 	if err != nil {
-		return nil, errs.Wrap(err)
+		return nil, err
 	}
 	return csr, nil
 }
