@@ -47,11 +47,7 @@ func (a *registrationEntries) captureChangedEntries(ctx context.Context) error {
 		return err
 	}
 	a.selectPolledEvents(ctx)
-	if err := a.scanForNewEvents(ctx); err != nil {
-		return err
-	}
-
-	return nil
+	return a.scanForNewEvents(ctx)
 }
 
 func (a *registrationEntries) searchBeforeFirstEvent(ctx context.Context) error {
