@@ -11,6 +11,7 @@ import (
 	"encoding/pem"
 	"errors"
 	"fmt"
+	"maps"
 	"path"
 	"reflect"
 	"regexp"
@@ -102,9 +103,7 @@ func (fck *fakeCryptoKey) fetchFakeCryptoKeyVersions() map[string]*fakeCryptoKey
 	}
 
 	fakeCryptoKeyVersions := make(map[string]*fakeCryptoKeyVersion, len(fck.fakeCryptoKeyVersions))
-	for key, fakeCryptoKeyVersion := range fck.fakeCryptoKeyVersions {
-		fakeCryptoKeyVersions[key] = fakeCryptoKeyVersion
-	}
+	maps.Copy(fakeCryptoKeyVersions, fck.fakeCryptoKeyVersions)
 	return fakeCryptoKeyVersions
 }
 
@@ -160,9 +159,7 @@ func (fs *fakeStore) fetchFakeCryptoKeys() map[string]*fakeCryptoKey {
 	}
 
 	fakeCryptoKeys := make(map[string]*fakeCryptoKey, len(fs.fakeCryptoKeys))
-	for key, fakeCryptoKey := range fs.fakeCryptoKeys {
-		fakeCryptoKeys[key] = fakeCryptoKey
-	}
+	maps.Copy(fakeCryptoKeys, fs.fakeCryptoKeys)
 	return fakeCryptoKeys
 }
 
@@ -338,7 +335,7 @@ func (k *fakeKMSClient) setGetPublicKeySequentialErrs(fakeError error, count int
 	k.mu.Lock()
 	defer k.mu.Unlock()
 	fakeErrors := make([]error, count)
-	for i := 0; i < count; i++ {
+	for i := range count {
 		fakeErrors[i] = fakeError
 	}
 	k.getPublicKeyErrs = fakeErrors
