@@ -311,6 +311,10 @@ func (*PCAPlugin) PublishJWTKeyAndSubscribe(*upstreamauthorityv1.PublishJWTKeyRe
 	return status.Error(codes.Unimplemented, "publishing upstream is unsupported")
 }
 
+func (p *PCAPlugin) SubscribeToLocalBundle(req *upstreamauthorityv1.SubscribeToLocalBundleRequest, stream upstreamauthorityv1.UpstreamAuthority_SubscribeToLocalBundleServer) error {
+	return status.Error(codes.Unimplemented, "fetching upstream trust bundle is unsupported")
+}
+
 func (p *PCAPlugin) getConfig() (*configuration, error) {
 	p.mtx.Lock()
 	defer p.mtx.Unlock()
