@@ -635,7 +635,6 @@ func TestGetEndEntityName(t *testing.T) {
 			name:                 "defaultEndEntityName unset use uri",
 			defaultEndEntityName: "",
 			subject:              "",
-			dnsNames:             []string{""},
 			uris:                 []string{"https://blueelephant.example.com"},
 			ips:                  []string{"192.168.1.1"},
 
@@ -645,8 +644,6 @@ func TestGetEndEntityName(t *testing.T) {
 			name:                 "defaultEndEntityName unset use ip",
 			defaultEndEntityName: "",
 			subject:              "",
-			dnsNames:             []string{""},
-			uris:                 []string{""},
 			ips:                  []string{"192.168.1.1"},
 
 			expectedEndEntityName: "192.168.1.1",
@@ -737,9 +734,9 @@ func generateCSR(subject string, dnsNames []string, uris []string, ipAddresses [
 
 	if subject != "" {
 		// Split the subject into its individual parts
-		parts := strings.Split(subject, ",")
+		parts := strings.SplitSeq(subject, ",")
 
-		for _, part := range parts {
+		for part := range parts {
 			// Split the part into key and value
 			keyValue := strings.SplitN(part, "=", 2)
 
